@@ -1,3 +1,4 @@
+from operator import index
 import re
 from openpyxl.styles.colors import COLOR_INDEX
 from openpyxl.utils import get_column_letter
@@ -106,4 +107,10 @@ def empty_to_zero(value):
     if value is None or str(value).rstrip() == '':
         return 0
     else:
-        return value
\ No newline at end of file
+        return value
+
+def get_column_index_from_letter(letter):
+    return column_index_from_string(letter)
+
+def get_column_letter_from_index(index):
+    return get_column_letter(index)
\ No newline at end of file
